import React from "react";
import { SnackbarProvider } from "notistack";
import { Container, CssBaseline, StyledEngineProvider } from "@mui/material";
import { ThemeProvider } from "@mui/material/styles";
import { theme } from "../style/Theme";
import { UserProvider } from "../api/UserProvider";
import { NotificationProvider } from "../components/common/notification/Notifications";
import NavigationMenu from "../components/navigation/NavigationMenu";
import { MemoryRouter } from "react-router-dom";
import { DeployAPIProvider } from "../api/DeployApi";

export function RouterHarness({ children, initialHistory = ["/"] }) {
  return (
    <StyledEngineProvider injectFirst>
      <ThemeProvider theme={theme}>
        <CssBaseline />
        <MemoryRouter initialEntries={initialHistory}>
          <DeployAPIProvider>{children}</DeployAPIProvider>
        </MemoryRouter>
      </ThemeProvider>
    </StyledEngineProvider>
  );
}

export function AppHarness({ children, initialHistory = ["/"] }) {
  return (
    <SnackbarProvider
      preventDuplicate
      maxSnack="5"
    >
      <RouterHarness initialHistory={initialHistory}>
        <UserProvider>
          <NotificationProvider>
            <NavigationMenu>
              <Container>{children}</Container>
            </NavigationMenu>
          </NotificationProvider>
        </UserProvider>
      </RouterHarness>
    </SnackbarProvider>
  );
}
